@@ -15,7 +15,7 @@ class Process():
         self._filters = filters or []
         self._raise_if_error = raise_if_error
 
-    def execute(self, args):
+    def execute(self, args, log_error=True):
         for index, arg in enumerate(args):
             if not isinstance(arg, str):
                 raise TypeError(
@@ -35,7 +35,7 @@ class Process():
             process.wait()
 
             exitcode = process.returncode
-            if exitcode:
+            if exitcode and log_error:
                 logger.warning(
                     "“%s” failed with exit code %s." % (log_command, exitcode))
 
